Class: OpenapiClient::ClientApi

Inherits:
Object
  • Object
show all
Defined in:
lib/ff/ruby/server/generated/lib/openapi_client/api/client_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ ClientApi

Returns a new instance of ClientApi.



19
20
21
# File 'lib/ff/ruby/server/generated/lib/openapi_client/api/client_api.rb', line 19

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



17
18
19
# File 'lib/ff/ruby/server/generated/lib/openapi_client/api/client_api.rb', line 17

def api_client
  @api_client
end

Instance Method Details

#authenticate(opts = {}) ⇒ AuthenticationResponse

Authenticate with the admin server. Used to retrieve all target segments for certain account id.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

Returns:



27
28
29
30
# File 'lib/ff/ruby/server/generated/lib/openapi_client/api/client_api.rb', line 27

def authenticate(opts = {})
  data, _status_code, _headers = authenticate_with_http_info(opts)
  data
end

#authenticate_with_http_info(opts = {}) ⇒ Array<(AuthenticationResponse, Integer, Hash)>

Authenticate with the admin server. Used to retrieve all target segments for certain account id.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

Returns:

  • (Array<(AuthenticationResponse, Integer, Hash)>)

    AuthenticationResponse data, response status code and response headers



37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
# File 'lib/ff/ruby/server/generated/lib/openapi_client/api/client_api.rb', line 37

def authenticate_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: ClientApi.authenticate ...'
  end
  # resource path
  local_var_path = '/client/auth'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  header_params['Content-Type'] = @api_client.select_header_content_type(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(opts[:'authentication_request'])

  # return_type
  return_type = opts[:debug_return_type] || 'AuthenticationResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || []

  new_options = opts.merge(
    :operation => :"ClientApi.authenticate",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: ClientApi#authenticate\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_all_segments(environment_uuid, opts = {}) ⇒ Array<Segment>

Retrieve all segments. Used to retrieve all segments for certain account id.

Parameters:

  • environment_uuid (String)

    Unique identifier for the environment object in the API.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



88
89
90
91
# File 'lib/ff/ruby/server/generated/lib/openapi_client/api/client_api.rb', line 88

def get_all_segments(environment_uuid, opts = {})
  data, _status_code, _headers = get_all_segments_with_http_info(environment_uuid, opts)
  data
end

#get_all_segments_with_http_info(environment_uuid, opts = {}) ⇒ Array<(Array<Segment>, Integer, Hash)>

Retrieve all segments. Used to retrieve all segments for certain account id.

Parameters:

  • environment_uuid (String)

    Unique identifier for the environment object in the API.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(Array<Segment>, Integer, Hash)>)

    Array<Segment> data, response status code and response headers



98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
# File 'lib/ff/ruby/server/generated/lib/openapi_client/api/client_api.rb', line 98

def get_all_segments_with_http_info(environment_uuid, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: ClientApi.get_all_segments ...'
  end
  # verify the required parameter 'environment_uuid' is set
  if @api_client.config.client_side_validation && environment_uuid.nil?
    fail ArgumentError, "Missing the required parameter 'environment_uuid' when calling ClientApi.get_all_segments"
  end
  # resource path
  local_var_path = '/client/env/{environmentUUID}/target-segments'.sub('{' + 'environmentUUID' + '}', CGI.escape(environment_uuid.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'Array<Segment>'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['BearerAuth']

  new_options = opts.merge(
    :operation => :"ClientApi.get_all_segments",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: ClientApi#get_all_segments\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_evaluation_by_identifier(environment_uuid, feature, target, opts = {}) ⇒ Evaluation

Get feature evaluations for target

Parameters:

  • environment_uuid (String)

    Unique identifier for the environment object in the API.

  • feature (String)

    Unique identifier for the flag object in the API.

  • target (String)

    Unique identifier for the target object in the API.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



152
153
154
155
# File 'lib/ff/ruby/server/generated/lib/openapi_client/api/client_api.rb', line 152

def get_evaluation_by_identifier(environment_uuid, feature, target, opts = {})
  data, _status_code, _headers = get_evaluation_by_identifier_with_http_info(environment_uuid, feature, target, opts)
  data
end

#get_evaluation_by_identifier_with_http_info(environment_uuid, feature, target, opts = {}) ⇒ Array<(Evaluation, Integer, Hash)>

Get feature evaluations for target

Parameters:

  • environment_uuid (String)

    Unique identifier for the environment object in the API.

  • feature (String)

    Unique identifier for the flag object in the API.

  • target (String)

    Unique identifier for the target object in the API.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(Evaluation, Integer, Hash)>)

    Evaluation data, response status code and response headers



163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
# File 'lib/ff/ruby/server/generated/lib/openapi_client/api/client_api.rb', line 163

def get_evaluation_by_identifier_with_http_info(environment_uuid, feature, target, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: ClientApi.get_evaluation_by_identifier ...'
  end
  # verify the required parameter 'environment_uuid' is set
  if @api_client.config.client_side_validation && environment_uuid.nil?
    fail ArgumentError, "Missing the required parameter 'environment_uuid' when calling ClientApi.get_evaluation_by_identifier"
  end
  # verify the required parameter 'feature' is set
  if @api_client.config.client_side_validation && feature.nil?
    fail ArgumentError, "Missing the required parameter 'feature' when calling ClientApi.get_evaluation_by_identifier"
  end
  # verify the required parameter 'target' is set
  if @api_client.config.client_side_validation && target.nil?
    fail ArgumentError, "Missing the required parameter 'target' when calling ClientApi.get_evaluation_by_identifier"
  end
  # resource path
  local_var_path = '/client/env/{environmentUUID}/target/{target}/evaluations/{feature}'.sub('{' + 'environmentUUID' + '}', CGI.escape(environment_uuid.to_s)).sub('{' + 'feature' + '}', CGI.escape(feature.to_s)).sub('{' + 'target' + '}', CGI.escape(target.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'Evaluation'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['BearerAuth']

  new_options = opts.merge(
    :operation => :"ClientApi.get_evaluation_by_identifier",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: ClientApi#get_evaluation_by_identifier\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_evaluations(environment_uuid, target, opts = {}) ⇒ Pagination

Get feature evaluations for target

Parameters:

  • environment_uuid (String)

    Unique identifier for the environment object in the API.

  • target (String)

    Unique identifier for the target object in the API.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



224
225
226
227
# File 'lib/ff/ruby/server/generated/lib/openapi_client/api/client_api.rb', line 224

def get_evaluations(environment_uuid, target, opts = {})
  data, _status_code, _headers = get_evaluations_with_http_info(environment_uuid, target, opts)
  data
end

#get_evaluations_with_http_info(environment_uuid, target, opts = {}) ⇒ Array<(Pagination, Integer, Hash)>

Get feature evaluations for target

Parameters:

  • environment_uuid (String)

    Unique identifier for the environment object in the API.

  • target (String)

    Unique identifier for the target object in the API.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(Pagination, Integer, Hash)>)

    Pagination data, response status code and response headers



234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
# File 'lib/ff/ruby/server/generated/lib/openapi_client/api/client_api.rb', line 234

def get_evaluations_with_http_info(environment_uuid, target, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: ClientApi.get_evaluations ...'
  end
  # verify the required parameter 'environment_uuid' is set
  if @api_client.config.client_side_validation && environment_uuid.nil?
    fail ArgumentError, "Missing the required parameter 'environment_uuid' when calling ClientApi.get_evaluations"
  end
  # verify the required parameter 'target' is set
  if @api_client.config.client_side_validation && target.nil?
    fail ArgumentError, "Missing the required parameter 'target' when calling ClientApi.get_evaluations"
  end
  # resource path
  local_var_path = '/client/env/{environmentUUID}/target/{target}/evaluations'.sub('{' + 'environmentUUID' + '}', CGI.escape(environment_uuid.to_s)).sub('{' + 'target' + '}', CGI.escape(target.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'Pagination'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['BearerAuth']

  new_options = opts.merge(
    :operation => :"ClientApi.get_evaluations",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: ClientApi#get_evaluations\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_feature_config(environment_uuid, opts = {}) ⇒ Array<FeatureConfig>

Get all feature flags activations All feature flags with activations in project environment

Parameters:

  • environment_uuid (String)

    Unique identifier for the environment object in the API.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



291
292
293
294
# File 'lib/ff/ruby/server/generated/lib/openapi_client/api/client_api.rb', line 291

def get_feature_config(environment_uuid, opts = {})
  data, _status_code, _headers = get_feature_config_with_http_info(environment_uuid, opts)
  data
end

#get_feature_config_by_identifier(identifier, environment_uuid, opts = {}) ⇒ FeatureConfig

Get feature config

Parameters:

  • identifier (String)

    Unique identifier for the flag object in the API.

  • environment_uuid (String)

    Unique identifier for the environment object in the API.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



354
355
356
357
# File 'lib/ff/ruby/server/generated/lib/openapi_client/api/client_api.rb', line 354

def get_feature_config_by_identifier(identifier, environment_uuid, opts = {})
  data, _status_code, _headers = get_feature_config_by_identifier_with_http_info(identifier, environment_uuid, opts)
  data
end

#get_feature_config_by_identifier_with_http_info(identifier, environment_uuid, opts = {}) ⇒ Array<(FeatureConfig, Integer, Hash)>

Get feature config

Parameters:

  • identifier (String)

    Unique identifier for the flag object in the API.

  • environment_uuid (String)

    Unique identifier for the environment object in the API.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(FeatureConfig, Integer, Hash)>)

    FeatureConfig data, response status code and response headers



364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
# File 'lib/ff/ruby/server/generated/lib/openapi_client/api/client_api.rb', line 364

def get_feature_config_by_identifier_with_http_info(identifier, environment_uuid, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: ClientApi.get_feature_config_by_identifier ...'
  end
  # verify the required parameter 'identifier' is set
  if @api_client.config.client_side_validation && identifier.nil?
    fail ArgumentError, "Missing the required parameter 'identifier' when calling ClientApi.get_feature_config_by_identifier"
  end
  # verify the required parameter 'environment_uuid' is set
  if @api_client.config.client_side_validation && environment_uuid.nil?
    fail ArgumentError, "Missing the required parameter 'environment_uuid' when calling ClientApi.get_feature_config_by_identifier"
  end
  # resource path
  local_var_path = '/client/env/{environmentUUID}/feature-configs/{identifier}'.sub('{' + 'identifier' + '}', CGI.escape(identifier.to_s)).sub('{' + 'environmentUUID' + '}', CGI.escape(environment_uuid.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'FeatureConfig'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['BearerAuth']

  new_options = opts.merge(
    :operation => :"ClientApi.get_feature_config_by_identifier",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: ClientApi#get_feature_config_by_identifier\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_feature_config_with_http_info(environment_uuid, opts = {}) ⇒ Array<(Array<FeatureConfig>, Integer, Hash)>

Get all feature flags activations All feature flags with activations in project environment

Parameters:

  • environment_uuid (String)

    Unique identifier for the environment object in the API.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(Array<FeatureConfig>, Integer, Hash)>)

    Array<FeatureConfig> data, response status code and response headers



301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
# File 'lib/ff/ruby/server/generated/lib/openapi_client/api/client_api.rb', line 301

def get_feature_config_with_http_info(environment_uuid, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: ClientApi.get_feature_config ...'
  end
  # verify the required parameter 'environment_uuid' is set
  if @api_client.config.client_side_validation && environment_uuid.nil?
    fail ArgumentError, "Missing the required parameter 'environment_uuid' when calling ClientApi.get_feature_config"
  end
  # resource path
  local_var_path = '/client/env/{environmentUUID}/feature-configs'.sub('{' + 'environmentUUID' + '}', CGI.escape(environment_uuid.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'Array<FeatureConfig>'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['BearerAuth']

  new_options = opts.merge(
    :operation => :"ClientApi.get_feature_config",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: ClientApi#get_feature_config\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_segment_by_identifier(identifier, environment_uuid, opts = {}) ⇒ Segment

Retrieve a segment by identifier Used to retrieve a segment for a certain account id by identifier

Parameters:

  • identifier (String)

    Unique identifier for the segment object in the API

  • environment_uuid (String)

    Unique identifier for the environment object in the API

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



422
423
424
425
# File 'lib/ff/ruby/server/generated/lib/openapi_client/api/client_api.rb', line 422

def get_segment_by_identifier(identifier, environment_uuid, opts = {})
  data, _status_code, _headers = get_segment_by_identifier_with_http_info(identifier, environment_uuid, opts)
  data
end

#get_segment_by_identifier_with_http_info(identifier, environment_uuid, opts = {}) ⇒ Array<(Segment, Integer, Hash)>

Retrieve a segment by identifier Used to retrieve a segment for a certain account id by identifier

Parameters:

  • identifier (String)

    Unique identifier for the segment object in the API

  • environment_uuid (String)

    Unique identifier for the environment object in the API

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(Segment, Integer, Hash)>)

    Segment data, response status code and response headers



433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
# File 'lib/ff/ruby/server/generated/lib/openapi_client/api/client_api.rb', line 433

def get_segment_by_identifier_with_http_info(identifier, environment_uuid, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: ClientApi.get_segment_by_identifier ...'
  end
  # verify the required parameter 'identifier' is set
  if @api_client.config.client_side_validation && identifier.nil?
    fail ArgumentError, "Missing the required parameter 'identifier' when calling ClientApi.get_segment_by_identifier"
  end
  # verify the required parameter 'environment_uuid' is set
  if @api_client.config.client_side_validation && environment_uuid.nil?
    fail ArgumentError, "Missing the required parameter 'environment_uuid' when calling ClientApi.get_segment_by_identifier"
  end
  # resource path
  local_var_path = '/client/env/{environmentUUID}/target-segments/{identifier}'.sub('{' + 'identifier' + '}', CGI.escape(identifier.to_s)).sub('{' + 'environmentUUID' + '}', CGI.escape(environment_uuid.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'Segment'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['BearerAuth']

  new_options = opts.merge(
    :operation => :"ClientApi.get_segment_by_identifier",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: ClientApi#get_segment_by_identifier\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#stream(api_key, opts = {}) ⇒ nil

Stream endpoint.

Parameters:

  • api_key (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (nil)


489
490
491
492
# File 'lib/ff/ruby/server/generated/lib/openapi_client/api/client_api.rb', line 489

def stream(api_key, opts = {})
  stream_with_http_info(api_key, opts)
  nil
end

#stream_with_http_info(api_key, opts = {}) ⇒ Array<(nil, Integer, Hash)>

Stream endpoint.

Parameters:

  • api_key (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(nil, Integer, Hash)>)

    nil, response status code and response headers



498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
# File 'lib/ff/ruby/server/generated/lib/openapi_client/api/client_api.rb', line 498

def stream_with_http_info(api_key, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: ClientApi.stream ...'
  end
  # verify the required parameter 'api_key' is set
  if @api_client.config.client_side_validation && api_key.nil?
    fail ArgumentError, "Missing the required parameter 'api_key' when calling ClientApi.stream"
  end
  # resource path
  local_var_path = '/stream'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  header_params[:'API-Key'] = api_key

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type]

  # auth_names
  auth_names = opts[:debug_auth_names] || ['BearerAuth']

  new_options = opts.merge(
    :operation => :"ClientApi.stream",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: ClientApi#stream\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end