Class: OpenapiClient::Segment
- Inherits:
-
Object
- Object
- OpenapiClient::Segment
- Defined in:
- lib/ff/ruby/server/generated/lib/openapi_client/models/segment.rb
Instance Attribute Summary collapse
-
#created_at ⇒ Object
Returns the value of attribute created_at.
-
#environment ⇒ Object
Returns the value of attribute environment.
-
#excluded ⇒ Object
Returns the value of attribute excluded.
-
#identifier ⇒ Object
Unique identifier for the segment.
-
#included ⇒ Object
Returns the value of attribute included.
-
#modified_at ⇒ Object
Returns the value of attribute modified_at.
-
#name ⇒ Object
Name of the segment.
-
#rules ⇒ Object
An array of rules that can cause a user to be included in this segment.
-
#tags ⇒ Object
Returns the value of attribute tags.
-
#version ⇒ Object
Returns the value of attribute version.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Segment
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ Segment
Initializes the object
86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 |
# File 'lib/ff/ruby/server/generated/lib/openapi_client/models/segment.rb', line 86 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `OpenapiClient::Segment` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `OpenapiClient::Segment`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'identifier') self.identifier = attributes[:'identifier'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'environment') self.environment = attributes[:'environment'] end if attributes.key?(:'tags') if (value = attributes[:'tags']).is_a?(Array) self. = value end end if attributes.key?(:'included') if (value = attributes[:'included']).is_a?(Array) self.included = value end end if attributes.key?(:'excluded') if (value = attributes[:'excluded']).is_a?(Array) self.excluded = value end end if attributes.key?(:'rules') if (value = attributes[:'rules']).is_a?(Array) self.rules = value end end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] end if attributes.key?(:'modified_at') self.modified_at = attributes[:'modified_at'] end if attributes.key?(:'version') self.version = attributes[:'version'] end end |
Instance Attribute Details
#created_at ⇒ Object
Returns the value of attribute created_at.
35 36 37 |
# File 'lib/ff/ruby/server/generated/lib/openapi_client/models/segment.rb', line 35 def created_at @created_at end |
#environment ⇒ Object
Returns the value of attribute environment.
24 25 26 |
# File 'lib/ff/ruby/server/generated/lib/openapi_client/models/segment.rb', line 24 def environment @environment end |
#excluded ⇒ Object
Returns the value of attribute excluded.
30 31 32 |
# File 'lib/ff/ruby/server/generated/lib/openapi_client/models/segment.rb', line 30 def excluded @excluded end |
#identifier ⇒ Object
Unique identifier for the segment.
19 20 21 |
# File 'lib/ff/ruby/server/generated/lib/openapi_client/models/segment.rb', line 19 def identifier @identifier end |
#included ⇒ Object
Returns the value of attribute included.
28 29 30 |
# File 'lib/ff/ruby/server/generated/lib/openapi_client/models/segment.rb', line 28 def included @included end |
#modified_at ⇒ Object
Returns the value of attribute modified_at.
37 38 39 |
# File 'lib/ff/ruby/server/generated/lib/openapi_client/models/segment.rb', line 37 def modified_at @modified_at end |
#name ⇒ Object
Name of the segment.
22 23 24 |
# File 'lib/ff/ruby/server/generated/lib/openapi_client/models/segment.rb', line 22 def name @name end |
#rules ⇒ Object
An array of rules that can cause a user to be included in this segment.
33 34 35 |
# File 'lib/ff/ruby/server/generated/lib/openapi_client/models/segment.rb', line 33 def rules @rules end |
#tags ⇒ Object
Returns the value of attribute tags.
26 27 28 |
# File 'lib/ff/ruby/server/generated/lib/openapi_client/models/segment.rb', line 26 def @tags end |
#version ⇒ Object
Returns the value of attribute version.
39 40 41 |
# File 'lib/ff/ruby/server/generated/lib/openapi_client/models/segment.rb', line 39 def version @version end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
58 59 60 |
# File 'lib/ff/ruby/server/generated/lib/openapi_client/models/segment.rb', line 58 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
42 43 44 45 46 47 48 49 50 51 52 53 54 55 |
# File 'lib/ff/ruby/server/generated/lib/openapi_client/models/segment.rb', line 42 def self.attribute_map { :'identifier' => :'identifier', :'name' => :'name', :'environment' => :'environment', :'tags' => :'tags', :'included' => :'included', :'excluded' => :'excluded', :'rules' => :'rules', :'created_at' => :'createdAt', :'modified_at' => :'modifiedAt', :'version' => :'version' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
203 204 205 |
# File 'lib/ff/ruby/server/generated/lib/openapi_client/models/segment.rb', line 203 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
79 80 81 82 |
# File 'lib/ff/ruby/server/generated/lib/openapi_client/models/segment.rb', line 79 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
63 64 65 66 67 68 69 70 71 72 73 74 75 76 |
# File 'lib/ff/ruby/server/generated/lib/openapi_client/models/segment.rb', line 63 def self.openapi_types { :'identifier' => :'String', :'name' => :'String', :'environment' => :'String', :'tags' => :'Array<Tag>', :'included' => :'Array<Target>', :'excluded' => :'Array<Target>', :'rules' => :'Array<Clause>', :'created_at' => :'Integer', :'modified_at' => :'Integer', :'version' => :'Integer' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
173 174 175 176 177 178 179 180 181 182 183 184 185 186 |
# File 'lib/ff/ruby/server/generated/lib/openapi_client/models/segment.rb', line 173 def ==(o) return true if self.equal?(o) self.class == o.class && identifier == o.identifier && name == o.name && environment == o.environment && == o. && included == o.included && excluded == o.excluded && rules == o.rules && created_at == o.created_at && modified_at == o.modified_at && version == o.version end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 |
# File 'lib/ff/ruby/server/generated/lib/openapi_client/models/segment.rb', line 233 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = OpenapiClient.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
304 305 306 307 308 309 310 311 312 313 314 315 316 |
# File 'lib/ff/ruby/server/generated/lib/openapi_client/models/segment.rb', line 304 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 |
# File 'lib/ff/ruby/server/generated/lib/openapi_client/models/segment.rb', line 210 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.openapi_types.each_pair do |key, type| if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
190 191 192 |
# File 'lib/ff/ruby/server/generated/lib/openapi_client/models/segment.rb', line 190 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
196 197 198 |
# File 'lib/ff/ruby/server/generated/lib/openapi_client/models/segment.rb', line 196 def hash [identifier, name, environment, , included, excluded, rules, created_at, modified_at, version].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
150 151 152 153 154 155 156 157 158 159 160 161 |
# File 'lib/ff/ruby/server/generated/lib/openapi_client/models/segment.rb', line 150 def list_invalid_properties invalid_properties = Array.new if @identifier.nil? invalid_properties.push('invalid value for "identifier", identifier cannot be nil.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
280 281 282 |
# File 'lib/ff/ruby/server/generated/lib/openapi_client/models/segment.rb', line 280 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
286 287 288 289 290 291 292 293 294 295 296 297 298 |
# File 'lib/ff/ruby/server/generated/lib/openapi_client/models/segment.rb', line 286 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
274 275 276 |
# File 'lib/ff/ruby/server/generated/lib/openapi_client/models/segment.rb', line 274 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
165 166 167 168 169 |
# File 'lib/ff/ruby/server/generated/lib/openapi_client/models/segment.rb', line 165 def valid? return false if @identifier.nil? return false if @name.nil? true end |